@@ -42,7 +42,7 @@ class AnnotatorProperties(Params):
 
         Parameters
         ----------
-        *value : str
+        *value : List[str]
             Input columns for the annotator
         """
         if type(value[0]) == str or type(value[0]) == list:
